@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module HTTP
   class Client
     alias_method :__perform__, :perform
@@ -5,9 +7,7 @@ module HTTP
     def perform(request, options)
       return __perform__(request, options) unless webmock_enabled?
 
-      response = WebMockPerform.new(request) { __perform__(request, options) }.exec
-      options.features.each { |_name, feature| response = feature.wrap_response(response) }
-      response
+      WebMockPerform.new(request, options) { __perform__(request, options) }.exec
     end
 
     def webmock_enabled?
