@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 module HTTP
   class Request
     def webmock_signature
       request_body = if defined?(HTTP::Request::Body)
-                       ''.tap { |string| body.each { |part| string << part } }
+                       String.new.tap { |string| body.each { |part| string << part } }
                      else
                        body
                      end
